@@ -9,12 +9,13 @@ from textwrap import dedent
 
 import click
 from click.testing import CliRunner
+from pymysql.err import OperationalError
 
 from mycli.main import MyCli, cli, thanks_picker
 import mycli.packages.special
 from mycli.packages.special.main import COMMANDS as SPECIAL_COMMANDS
 from mycli.sqlexecute import ServerInfo, SQLExecute
-from test.utils import HOST, PASSWORD, PORT, USER, dbtest, run
+from test.utils import DATABASE, HOST, PASSWORD, PORT, USER, dbtest, run
 
 test_dir = os.path.abspath(os.path.dirname(__file__))
 project_dir = os.path.dirname(test_dir)
@@ -94,6 +95,41 @@ def test_ssl_mode_overrides_no_ssl(executor, capsys):
     assert ssl_cipher
 
 
+@dbtest
+def test_reconnect_database_is_selected(executor, capsys):
+    m = MyCli()
+    m.register_special_commands()
+    m.sqlexecute = SQLExecute(
+        None,
+        USER,
+        PASSWORD,
+        HOST,
+        PORT,
+        None,
+        None,
+        None,
+        None,
+        None,
+        None,
+        None,
+        None,
+        None,
+        None,
+    )
+    try:
+        next(m.sqlexecute.run(f"use {DATABASE}"))
+        next(m.sqlexecute.run(f"kill {m.sqlexecute.connection_id}"))
+    except OperationalError:
+        pass  # expected as the connection was killed
+    except Exception as e:
+        raise e
+    m.reconnect()
+    try:
+        next(m.sqlexecute.run("show tables")).results.fetchall()
+    except Exception as e:
+        raise e
+
+
 @dbtest
 def test_reconnect_no_database(executor, capsys):
     m = MyCli()
@@ -118,7 +154,7 @@ def test_reconnect_no_database(executor, capsys):
     sql = "\\r"
     result = next(mycli.packages.special.execute(executor, sql))
     stdout, _stderr = capsys.readouterr()
-    assert result[-1] is None
+    assert result.status is None
     assert "Already connected" in stdout
 
 
@@ -150,7 +186,7 @@ def test_reconnect_with_different_database(executor):
     _result_1 = next(mycli.packages.special.execute(executor, sql_1))
     result_2 = next(mycli.packages.special.execute(executor, sql_2))
     expected = f'You are now connected to database "{database_2}" as user "{USER}"'
-    assert expected in result_2[-1]
+    assert expected in result_2.status
 
 
 @dbtest
@@ -180,7 +216,7 @@ def test_reconnect_with_same_database(executor):
     sql = f"\\r {database}"
     result = next(mycli.packages.special.execute(executor, sql))
     expected = f'You are already connected to database "{database}" as user "{USER}"'
-    assert expected in result[-1]
+    assert expected in result.status
 
 
 @dbtest
